summary refs log tree commit diff
path: root/src/libnm-core-impl/tests/test-keyfile.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/libnm-core-impl/tests/test-keyfile.c')
-rw-r--r--src/libnm-core-impl/tests/test-keyfile.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/libnm-core-impl/tests/test-keyfile.c b/src/libnm-core-impl/tests/test-keyfile.c
index 9f546971..1912782e 100644
--- a/src/libnm-core-impl/tests/test-keyfile.c
+++ b/src/libnm-core-impl/tests/test-keyfile.c
@@ -196,7 +196,7 @@ _nm_keyfile_read(GKeyFile            *keyfile,
         {
             NMSettingConnection *s_con;
 
             /* a non-slave connection must have a proxy setting, but
              * keyfile reader does not add that (unless a [proxy] section
              * is present. */
             s_con = nm_connection_get_setting_connection(con);
@@ -857,8 +857,8 @@ test_bridge_port_vlans(void)
                                                   "id=t\n"
                                                   "type=dummy\n"
                                                   "interface-name=dummy1\n"
-                                                  "master=br0\n"
-                                                  "slave-type=bridge\n"
+                                                  "controller=br0\n"
+                                                  "port-type=bridge\n"
                                                   "\n"
                                                   "[bridge-port]\n"
                                                   "vlans=4094 pvid , 10-20 untagged\n"
@@ -196,7 +196,7 @@ _nm_keyfile_read(GKeyFile            *keyfile,
             NMSettingConnection *s_con;
 
-            /* a non-slave connection must have a proxy setting, but
+            /* a non-port connection must have a proxy setting, but
              * keyfile reader does not add that (unless a [proxy] section
              * is present. */